==> IceWarpServer-10.0.6_RHEL5.tar.gz: html/webmail/client/inc/frm_sharing.js <==
/*
#datagrid:
    - predelat na skin datagrid 2
    - zakazat move columns


        r(items read)
		i(items write)
		w(items modify)
		t(items delete)
		l(folder read)
		k(folder write)
		m(folder modify)
		x(folder delete)
		a(admin/owner)
		
		lrswipkcdexta
		
		SPCDET

*/

_me = frm_sharing.prototype;
function frm_sharing(){};

_me.__constructor = function(aFolderInfo){

	this.__aFolderInfo = aFolderInfo;

	var me = this;

	this._size(470,460,true);
	this._resizable = false;

	this.__bFormEnabled = false;
	
	this._title(getLang('POPUP_FOLDERS::SHARING')+' ('+(aFolderInfo.fid?aFolderInfo.fid.replace(/^\~/g,''):aFolderInfo.aid)+')',true);

	this._draw('frm_sharing','main');

	// Create 'OK' button
	this._create('x_btn_ok', 'obj_button', 'footer');
	this.x_btn_ok._disabled(true);
	this.x_btn_ok._value('FORM_BUTTONS::OK');
	this.x_btn_ok._onclick = function() {
		me.__save();
		me._destruct();
	};

	// Create 'INHERITE' button
	if (aFolderInfo.fid){
		this._create('x_btn_inherit', 'obj_button', 'footer');
		this.x_btn_inherit._disabled(true);

		this.x_btn_inherit._value('FORM_BUTTONS::INHERIT');
		this.x_btn_inherit._onclick = function() {
			//SMAZ PRAVA
			me.__aData = {};
			me.x_btn_ok._onclick();
		};
	}


	// Create 'CANCEL' button
	this._create('x_btn_cancel', 'obj_button', 'footer');
	this.x_btn_cancel._value('FORM_BUTTONS::CANCEL');
	this.x_btn_cancel._onclick = function() { me._destruct(); };

	//ok
	this.users._addColumns({user:{title:"SHARING::USER",width:250,type:'static'},
				a:{text:"A",width:23,css:'col_a',type:'static'},
				r:{text:"R",width:23,css:'col_r',type:'static'},
				i:{text:"W",width:23,css:'col_i',type:'static'},
				w:{text:"M",width:23,css:'col_w',type:'static'},
				t:{text:"D",width:23,css:'col_t',type:'static'},
				l:{text:"R",width:23,css:'col_l',type:'static'},
				k:{text:"W",width:23,css:'col_k',type:'static'},
				x:{text:"D",width:23,css:'col_x',type:'static'}});


	//Load Data
	var bEnable = true;
	try{
		this.__aData  = {'anyone':[]};

		var tmp
		if (this.__aFolderInfo.fid)
			tmp = WMFolders.list(this.__aFolderInfo)[this.__aFolderInfo.aid][this.__aFolderInfo.fid];
		else
			tmp = WMAccounts.list(this.__aFolderInfo)[this.__aFolderInfo.aid];

		if (tmp){
			if (tmp.RIGHTS && tmp.RIGHTS.indexOf('a')<0)
			    bEnable = false;
			    
			tmp = tmp.ACL;
		}

		for(var i in tmp)
			this.__aData[i]  = tmp[i];

		tmp = null;
	}
	catch(r){
		this.__aData = {'anyone':[]};
		bEnable = true;
	}

	var bPublic = dataSet.get('folders',[aFolderInfo.aid,aFolderInfo.fid,'PUBLIC']);

	//check for shared folder
	if (this.__aFolderInfo && this.__aFolderInfo.fid && (this.__aFolderInfo.fid.indexOf('~') === 0 || bPublic)){
		var tmp = this.__aFolderInfo.fid.split('/');
			tmp = tmp[0];
			
		if (bPublic || tmp.indexOf('@')>0){
			var a = this.__aData[sPrimaryAccount] || this.__aData.anyone;
			if (Is.Array(a) && inArray(a,'a')>-1){
				//Enable All
				this.__bFormEnabled = true;
				this.add._disabled(false);
				this.remove._disabled(false);
				this.x_btn_ok._disabled(false);
				this.x_btn_inherit._disabled(false);
			}
		}
	}
	//Enable All
	else
	if (bEnable){
		this.__bFormEnabled = true;
		this.add._disabled(false);
		this.remove._disabled(false);
		this.x_btn_ok._disabled(false);
		if (this.x_btn_inherit)
			this.x_btn_inherit._disabled(false);
	}
	
	this.__aData2 = clone(this.__aData,true);

	this._fill();

	//prepare checkboxes
	var sync = function (){

		var tmp = [],
			v1 = me.ch_item._value(),
			a1 = ['r','i','w','t'],
			v2 = me.ch_folder._value(),
			a2 = ['a','l','k','x'];

		for(var i in v1)
			tmp.push(a1[v1[i]]);

		for(var i in v2)
			tmp.push(a2[v2[i]]);

		var v = me.users._value();
		for (var i in v)
			if (typeof v[i] != 'undefined')
				me.__aData[me.users._aData[v[i]].arg.user] = tmp;

		me._fill();
	};


	this.ch_item._useslang = true;
	this.ch_item._fill(['SETTINGS::READ','SETTINGS::WRITE','SETTINGS::MODIFY','SETTINGS::DELETE']);
	this.ch_item._disabled(true);

	this.ch_item._onclick = sync;

	this.ch_folder._useslang = true;
	this.ch_folder._fill(['SETTINGS::OWNER','SETTINGS::READ','SETTINGS::WRITE','SETTINGS::DELETE']);
	this.ch_folder._disabled(true);
	this.ch_folder._onclick = sync;

	function updateCheckLists (aData){
		var tmpF = [],//[false,false,false,false],
			tmpI = [];//[false,false,false,false];

		for(var i in aData)
			switch(aData[i]){
			case 'r':
				tmpI.push(0);
				break;
			case 'i':
				tmpI.push(1);
				break;
			case 'w':
				tmpI.push(2);
				break;
			case 't':
				tmpI.push(3);
				break;

			case 'a':
				tmpF.push(0);
				break;
			case 'l':
				tmpF.push(1);
				break;
			case 'k':
				tmpF.push(2);
				break;
			case 'x':
				tmpF.push(3);
				break;
			}

		me.ch_item._value(tmpI);
		me.ch_item._disabled(false);
		me.ch_folder._value(tmpF);
		me.ch_folder._disabled(false);
	};

	//ok
	this.users._onclick = function (e,elm,arg,row,cell){
		if (me.__bFormEnabled && arg && arg.user && Is.Array(me.__aData[arg.user])){
			if (cell != 'user'){
				var p;
				if ((p = inArray(me.__aData[arg.user],cell))>-1)
					me.__aData[arg.user].splice(p,1);
				else
					me.__aData[arg.user].push(cell);

				me._fill();
			}

			updateCheckLists(me.__aData[arg.user]);
		}
	};
	
	//ok
	this.add._onclick = function (){
		var frm = gui._create('address_book', 'frm_addaddress', '', '',[me, '__onAddNewFromAddressbook'], ['ADDRESS_BOOK::SELECT_ADDRESSES'],[''],'','',2);
	};

	//ok
	this.remove._onclick = function (){
		var v = me.users._value();
		if (!v || !v[0] || v[0]<1) return;

		try{
			me.__aData[me.users._aData[v[0]].arg.user] = ['~'];
			me._fill();
		}
		catch(e){}

		if (!me.users._aData[v[0]] && me.users._aData.length>0){
			v = [me.users._aData.length-1];
			me.users._value(v);
		}

		if (me.users._aData[v[0]])
			updateCheckLists(me.users._aData[v[0]].arg.rights);
		else{
			me.ch_item._disabled(true);
			me.ch_item._value([]);
			me.ch_folder._disabled(true);
			me.ch_folder._value([]);
		}
	};
};

//ok
_me._fill = function(){
	var aData = [];
	for(var i in this.__aData)
		if (this.__aData[i][0]!='~')
			aData.push({data:{user:(i=='anyone'?getLang('SHARING::EVERYONE'):i.escapeHTML())}, arg:{user:i,rights:this.__aData[i]}, css:Is.Array(this.__aData[i])?this.__aData[i].join(' '):''});

	this.users._fill(aData);
};

//ok
_me.__onAddNewFromAddressbook = function(bOK, aAddresses){

	if (bOK && aAddresses && aAddresses[0]){
		var tmp;
		for(var i in aAddresses[0]){
			tmp = MailAddress.splitEmailsAndNames(aAddresses[0][i]);
			if (tmp && (tmp = tmp[0]) && tmp.email && (!this.__aData[tmp.email] || this.__aData[tmp.email][0]=='~'))
				this.__aData[tmp.email] = ['r','l'];
		}

		this._fill();
	}
};

//ok
_me.__save = function(){

	if (!Is.Empty(this.__aData)){
		for(var i in this.__aData2)
			if (this.__aData[i] && arrayCompare(this.__aData2[i],this.__aData[i]))
				delete this.__aData[i];
				
		//No change, do not save
		if (Is.Empty(this.__aData))
		    return;
	}

	this.__aFolderInfo.acl = this.__aData;
	if (this.__aFolderInfo.fid)
		WMFolders.add(this.__aFolderInfo,'null');
	else
		WMAccounts.add(this.__aFolderInfo,'null');
};

==> IceWarpServer-10.1.4_RHEL5.tar.gz: html/webmail/client/inc/frm_sharing.js <==
/*
#datagrid:
    - predelat na skin datagrid 2
    - zakazat move columns


        r(items read)
		i(items write)
		w(items modify)
		t(items delete)
		l(folder read)
		k(folder write)
		m(folder modify)
		x(folder delete)
		a(admin/owner)
		
		lrswipkcdexta
		
		SPCDET

*/

_me = frm_sharing.prototype;
function frm_sharing(){};

_me.__constructor = function(aFolderInfo){

	this.__aFolderInfo = aFolderInfo;

	var me = this;

	this._size(470,460,true);
	this._resizable = false;

	this.__bFormEnabled = false;
	
	this._title(getLang('POPUP_FOLDERS::SHARING')+' ('+(aFolderInfo.fid?aFolderInfo.fid.replace(/^\~/g,''):aFolderInfo.aid)+')',true);

	this._draw('frm_sharing','main');

	// Create 'OK' button
	this._create('x_btn_ok', 'obj_button', 'footer');
	this.x_btn_ok._disabled(true);
	this.x_btn_ok._value('FORM_BUTTONS::OK');
	this.x_btn_ok._onclick = function() {
		me.__save();
		me._destruct();
	};

	// Create 'INHERITE' button
	if (aFolderInfo.fid){
		this._create('x_btn_inherit', 'obj_button', 'footer');
		this.x_btn_inherit._disabled(true);

		this.x_btn_inherit._value('FORM_BUTTONS::INHERIT');
		this.x_btn_inherit._onclick = function() {
			//SMAZ PRAVA
			me.__aData = {};
			me.x_btn_ok._onclick();
		};
	}


	// Create 'CANCEL' button
	this._create('x_btn_cancel', 'obj_button', 'footer');
	this.x_btn_cancel._value('FORM_BUTTONS::CANCEL');
	this.x_btn_cancel._onclick = function() { me._destruct(); };

	//ok
	this.users._addColumns({user:{title:"SHARING::USER",width:250,type:'static'},
				a:{text:"A",width:23,css:'col_a',type:'static'},
				r:{text:"R",width:23,css:'col_r',type:'static'},
				i:{text:"W",width:23,css:'col_i',type:'static'},
				w:{text:"M",width:23,css:'col_w',type:'static'},
				t:{text:"D",width:23,css:'col_t',type:'static'},
				l:{text:"R",width:23,css:'col_l',type:'static'},
				k:{text:"W",width:23,css:'col_k',type:'static'},
				x:{text:"D",width:23,css:'col_x',type:'static'}});


	//Load Data
	var bEnable = true;
	try{
		this.__aData  = {'anyone':[]};

		var tmp
		if (this.__aFolderInfo.fid)
			tmp = WMFolders.list(this.__aFolderInfo)[this.__aFolderInfo.aid][this.__aFolderInfo.fid];
		else
			tmp = WMAccounts.list(this.__aFolderInfo)[this.__aFolderInfo.aid];

		if (tmp){
			if (tmp.RIGHTS && tmp.RIGHTS.indexOf('a')<0)
			    bEnable = false;
			    
			tmp = tmp.ACL;
		}

		for(var i in tmp)
			this.__aData[i]  = tmp[i];

		tmp = null;
	}
	catch(r){
		this.__aData = {'anyone':[]};
		bEnable = true;
	}

	var bPublic = dataSet.get('folders',[aFolderInfo.aid,aFolderInfo.fid,'PUBLIC']);

	//check for shared folder
	if (this.__aFolderInfo && this.__aFolderInfo.fid && (this.__aFolderInfo.fid.indexOf('~') === 0 || bPublic)){
		var tmp = this.__aFolderInfo.fid.split('/');
			tmp = tmp[0];
			
		if (bPublic || tmp.indexOf('@')>0){
			var a = this.__aData[sPrimaryAccount] || this.__aData.anyone;
			if (Is.Array(a) && inArray(a,'a')>-1){
				//Enable All
				this.__bFormEnabled = true;
				this.add._disabled(false);
				this.remove._disabled(false);
				this.x_btn_ok._disabled(false);
				this.x_btn_inherit._disabled(false);
			}
		}
	}
	//Enable All
	else
	if (bEnable){
		this.__bFormEnabled = true;
		this.add._disabled(false);
		this.remove._disabled(false);
		this.x_btn_ok._disabled(false);
		if (this.x_btn_inherit)
			this.x_btn_inherit._disabled(false);
	}
	
	this.__aData2 = clone(this.__aData,true);

	this._fill();

	//prepare checkboxes
	var sync = function (){

		var tmp = [],
			v1 = me.ch_item._value(),
			a1 = ['r','i','w','t'],
			v2 = me.ch_folder._value(),
			a2 = ['a','l','k','x'];

		for(var i in v1)
			tmp.push(a1[v1[i]]);

		for(var i in v2)
			tmp.push(a2[v2[i]]);

		var v = me.users._value();
		for (var i in v)
			if (typeof v[i] != 'undefined')
				me.__aData[me.users._aData[v[i]].arg.user] = tmp;

		me._fill();
	};


	this.ch_item._useslang = true;
	this.ch_item._fill(['SETTINGS::READ','SETTINGS::WRITE','SETTINGS::MODIFY','SETTINGS::DELETE']);
	this.ch_item._disabled(true);

	this.ch_item._onclick = sync;

	this.ch_folder._useslang = true;
	this.ch_folder._fill(['SETTINGS::OWNER','SETTINGS::READ','SETTINGS::WRITE','SETTINGS::DELETE']);
	this.ch_folder._disabled(true);
	this.ch_folder._onclick = sync;

	function updateCheckLists (aData){
		var tmpF = [],//[false,false,false,false],
			tmpI = [];//[false,false,false,false];

		for(var i in aData)
			switch(aData[i]){
			case 'r':
				tmpI.push(0);
				break;
			case 'i':
				tmpI.push(1);
				break;
			case 'w':
				tmpI.push(2);
				break;
			case 't':
				tmpI.push(3);
				break;

			case 'a':
				tmpF.push(0);
				break;
			case 'l':
				tmpF.push(1);
				break;
			case 'k':
				tmpF.push(2);
				break;
			case 'x':
				tmpF.push(3);
				break;
			}

		me.ch_item._value(tmpI);
		me.ch_item._disabled(false);
		me.ch_folder._value(tmpF);
		me.ch_folder._disabled(false);
	};

	//ok
	this.users._onclick = function (e,elm,arg,row,cell){
		if (me.__bFormEnabled && arg && arg.user && Is.Array(me.__aData[arg.user])){
			if (cell != 'user'){
				var p;
				if ((p = inArray(me.__aData[arg.user],cell))>-1)
					me.__aData[arg.user].splice(p,1);
				else
					me.__aData[arg.user].push(cell);

				me._fill();
			}

			updateCheckLists(me.__aData[arg.user]);
		}
	};
	
	//ok
	this.add._onclick = function (){
		var frm = gui._create('address_book', 'frm_addaddress', '', '',[me, '__onAddNewFromAddressbook'], ['ADDRESS_BOOK::SELECTED_ADDRESSES'],[''],'','',2);
	};

	//ok
	this.remove._onclick = function (){
		var v = me.users._value();
		if (!v || !v[0] || v[0]<1) return;

		try{
			me.__aData[me.users._aData[v[0]].arg.user] = ['~'];
			me._fill();
		}
		catch(e){}

		if (!me.users._aData[v[0]] && me.users._aData.length>0){
			v = [me.users._aData.length-1];
			me.users._value(v);
		}

		if (me.users._aData[v[0]])
			updateCheckLists(me.users._aData[v[0]].arg.rights);
		else{
			me.ch_item._disabled(true);
			me.ch_item._value([]);
			me.ch_folder._disabled(true);
			me.ch_folder._value([]);
		}
	};
};

//ok
_me._fill = function(){
	var aData = [];
	for(var i in this.__aData)
		if (this.__aData[i][0]!='~')
			aData.push({data:{user:(i=='anyone'?getLang('SHARING::EVERYONE'):i.escapeHTML())}, arg:{user:i,rights:this.__aData[i]}, css:Is.Array(this.__aData[i])?this.__aData[i].join(' '):''});

	this.users._fill(aData);
};

//ok
_me.__onAddNewFromAddressbook = function(bOK, aAddresses){

	if (bOK && aAddresses && aAddresses[0]){
		var tmp;
		for(var i in aAddresses[0]){
			tmp = MailAddress.splitEmailsAndNames(aAddresses[0][i]);
			if (tmp && (tmp = tmp[0]) && tmp.email && (!this.__aData[tmp.email] || this.__aData[tmp.email][0]=='~'))
				this.__aData[tmp.email] = ['r','l'];
		}

		this._fill();
	}
};

//ok
_me.__save = function(){

	if (!Is.Empty(this.__aData)){
		for(var i in this.__aData2)
			if (this.__aData[i] && arrayCompare(this.__aData2[i],this.__aData[i]))
				delete this.__aData[i];
				
		//No change, do not save
		if (Is.Empty(this.__aData))
		    return;
	}

	this.__aFolderInfo.acl = this.__aData;
	if (this.__aFolderInfo.fid)
		WMFolders.add(this.__aFolderInfo,'null');
	else
		WMAccounts.add(this.__aFolderInfo,'null');
};
